@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Carp qw/croak/;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 require XSLoader;
 XSLoader::load('Class::XSAccessor', $VERSION);
@@ -105,6 +105,10 @@ The lower factor applies to the potentially slightly obscure
 C<sub set_foo_pp {$_[0]-E<gt>{foo} = $_[1]}>, so if you usually
 write clear code, a factor of two speed-up is a good estimate.
 
+The method names may be fully qualified. In the example of the
+synopsis, you could have written C<MyClass::get_foo> instead
+of C<get_foo>.
+
 =head1 CAVEATS
 
 Probably wouldn't work if your objects are I<tied> hashes. But that's a strange thing to do anyway.
